==> iwmutlis-0.0.3.tar.gz: iwmutlis-0.0.3/iwmcrt/iwmcrt.h <==
/*
copyright (c) 2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#ifndef _IWMCRT_H_
#define _IWMCRT_H_


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


typedef void (__cdecl *_PVFV)(void);


void __cdecl _initterm (_PVFV *, _PVFV *);


extern _PVFV *__onexitbegin;
extern _PVFV *__onexitend;
extern _PVFV __xc_a[];
extern _PVFV __xc_z[];
extern _PVFV __xi_a[];
extern _PVFV __xi_z[];


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* _IWMCRT_H_ */

==> iwmutlis-0.0.5.tar.gz: iwmutlis-0.0.5/iwmcrt/iwmcrt.h <==
/*
copyright (c) 2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#ifndef _IWMCRT_H_
#define _IWMCRT_H_


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


typedef int  (__cdecl *_PIFV)(void);
typedef void (__cdecl *_PVFV)(void);


void __cdecl _initterm (_PVFV *, _PVFV *);


extern _PVFV *__onexitbegin;
extern _PVFV *__onexitend;

#pragma section (".CRT$XCA", long, read)
#pragma section (".CRT$XCZ", long, read)
#pragma section (".CRT$XIA", long, read)
#pragma section (".CRT$XIZ", long, read)
extern __declspec (allocate (".CRT$XCA")) _PVFV __xc_a[];
extern __declspec (allocate (".CRT$XCZ")) _PVFV __xc_z[];
extern __declspec (allocate (".CRT$XIA")) _PIFV __xi_a[];
extern __declspec (allocate (".CRT$XIZ")) _PIFV __xi_z[];


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* _IWMCRT_H_ */
